@@ -495,14 +495,7 @@ def sessions_transforms(sessions, ramps, access_groups, devices):
                     days=365 - int(number))
 
     # YEAR
-    sessions.loc[this_start.year - sessions['Session Start'].dt.year == 0, 'Year'] = 'This Year'
-    sessions.loc[this_start.year - sessions['Session Start'].dt.year == 1, 'Year'] = 'Last Year'
-    sessions.loc[this_start.year - sessions['Session Start'].dt.year > 1, 'Year'] = str(
-        this_start.year - sessions['Session Start'].dt.year) + ' Years Ago'
-
-    sessions.loc[sessions['Session Start'] < datetime.strftime(this_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = 'Last Year'
-    sessions.loc[sessions['Session Start'] < datetime.strftime(last_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = str(
-        sessions['Year']) + ' Years Ago'
+    sessions['Year'] = sessions['Session Start'].dt.strftime('%Y')
 
     # DATA SOURCE
     sessions['Data Source'] = 'Designa'
@@ -630,14 +623,7 @@ def entries_transforms(entries, ramps, access_groups, devices):
                     days=365 - int(number))
 
     # YEAR
-    entries.loc[this_start.year - entries['Activity Time'].dt.year == 0, 'Year'] = 'This Year'
-    entries.loc[this_start.year - entries['Activity Time'].dt.year == 1, 'Year'] = 'Last Year'
-    entries.loc[this_start.year - entries['Activity Time'].dt.year > 1, 'Year'] = str(
-        this_start.year - entries['Activity Time'].dt.year) + ' Years Ago'
-
-    entries.loc[entries['Activity Time'] < datetime.strftime(this_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = 'Last Year'
-    entries.loc[entries['Activity Time'] < datetime.strftime(last_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = str(
-        entries['Year']) + ' Years Ago'
+    entries['Year'] = entries['Activity Time'].dt.strftime('%Y')
 
     # DATA SOURCE
     entries['Data Source'] = 'Designa'
@@ -753,14 +739,7 @@ def exits_transforms(exits, ramps, access_groups, devices):
                     days=365 - int(number))
 
     # YEAR
-    exits.loc[this_start.year - exits['Exit Time'].dt.year == 0, 'Year'] = 'This Year'
-    exits.loc[this_start.year - exits['Exit Time'].dt.year == 1, 'Year'] = 'Last Year'
-    exits.loc[this_start.year - exits['Exit Time'].dt.year > 1, 'Year'] = str(
-        this_start.year - exits['Exit Time'].dt.year) + ' Years Ago'
-
-    exits.loc[exits['Exit Time'] < datetime.strftime(this_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = 'Last Year'
-    exits.loc[exits['Exit Time'] < datetime.strftime(last_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = str(
-        exits['Year']) + ' Years Ago'
+    exits['Year'] = exits['Exit Time'].dt.strftime('%Y')
 
     # DATA SOURCE
     exits['Data Source'] = 'Designa'
@@ -836,15 +815,6 @@ def occupancy_transforms(occupancy):
     occupancy['Comparison Date'] = pd.to_datetime(occupancy['Comparison Date'], '%Y-%m-%d %H:%M:%S')
 
     # Convert Year Column to Filter by This, Last, and Previous Years
-    occupancy.loc[this_start.year - occupancy['Date'].dt.year == 0, 'Year'] = 'This Year'
-    occupancy.loc[this_start.year - occupancy['Date'].dt.year == 1, 'Year'] = 'Last Year'
-    occupancy.loc[this_start.year - occupancy['Date'].dt.year > 1, 'Year'] = str(
-        this_start.year - occupancy['Date'].dt.year) + ' Years Ago'
-
-    occupancy.loc[
-        occupancy['Date'] < datetime.strftime(this_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = 'Last Year'
-    occupancy.loc[
-        occupancy['Date'] < datetime.strftime(last_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = str(
-        occupancy['Year']) + ' Years Ago'
+    occupancy['Year'] = occupancy['Date'].dt.strftime('%Y')
 
     return occupancy
